#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QFileDialog>
#include <QMenu>
#include <QMenuBar>
#include <QVBoxLayout>
#include <QTreeView>
#include <QHeaderView>
#include <QStatusBar>
#include <QLabel>

#include "xmlparsingmodel.h"

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = nullptr);
    ~MainWindow();

private slots:
    void on_open_action_clicked();
    void on_close_action_clicked();
    void on_exit_action_clicked();
    void on_fullscreen_action_clicked();
    void on_make_active_action_clicked();
    void on_remove_action_clicked();
    void on_toggle_active_action_clicked();
    void on_toggle_all_action_clicked();
    void on_context_menu_requested(QPoint);

private:
    QAction* make_action(const QString& p_name, const QString& p_tip, const char* p_slot,
                         bool status_bar = true);
    QFileDialog* file_dialog;
    QVBoxLayout* main_layout;
    QMenu* menu;
    QMenu* context_menu;
    XMLParsingModel* model;
    XMLParsingModel* active_model;
    QTreeView* xml_view;
    QTreeView* xml_active_view;
    bool xml_view_empty;
    bool xml_active_view_empty;
    QModelIndex last_context_index;
    QLabel* active_view_label;
    QLabel* view_label;
};
#endif // MAINWINDOW_H
