#ifndef DOMMODEL_H
#define DOMMODEL_H

#include <QAbstractItemModel>
#include <QDomDocument>
#include <QFile>
#include <QDomNode>

class XMLParsingItem
{
public:
    XMLParsingItem(const QDomNode& p_node, int row, XMLParsingItem* parent = nullptr);
    ~XMLParsingItem();
    XMLParsingItem* child(int i);
    XMLParsingItem* parent();
    QDomNode node() const;
    int row() const;

private:
    QDomNode m_node;
    QHash<int, XMLParsingItem*> childItems;
    XMLParsingItem* parentItem;
    int rowNumber;

};

class XMLParsingModel : public QAbstractItemModel
{
    Q_OBJECT
public:
    explicit XMLParsingModel(const QStringList&, QObject* parent = nullptr);
    ~XMLParsingModel();

    QVariant data(const QModelIndex& p_idx, int role) const override;
    Qt::ItemFlags flags(const QModelIndex& p_idx) const override;
    QVariant headerData(int section, Qt::Orientation p_orient, int role = Qt::DisplayRole) const override;
    QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const override;
    QModelIndex parent(const QModelIndex& child) const override;

    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
    int columnCount(const QModelIndex& parent = QModelIndex()) const override;

    XMLParsingItem* get_root_item() const;

    void add_file(const QStringList& filename);
    void delete_file(const QModelIndex&);

    const QString& get_path(const QString&);

private:
    QStringList paths;
    QStringList filenames;
    QVector<QDomDocument> opened_docs;
    XMLParsingItem* root_item;

private:
    void set_tag_name(const QString&);

};

#endif // DOMMODEL_H
